package com.ruoyi.ss.access.service;

import com.ruoyi.ss.access.domain.Access;
import com.ruoyi.ss.access.domain.AccessQuery;
import com.ruoyi.ss.access.domain.AccessVO;
import com.ruoyi.ss.access.domain.vo.AccessApplyVO;
import com.ruoyi.ss.user.domain.SmUserVo;

import java.util.List;

/**
 * 第三方API秘钥对Service接口
 *
 * @author ruoyi
 * @date 2024-07-17
 */
public interface AccessService
{
    /**
     * 查询第三方API秘钥对
     *
     * @param accessId 第三方API秘钥对主键
     * @return 第三方API秘钥对
     */
    public AccessVO selectAccessByAccessId(Long accessId);

    /**
     * 查询第三方API秘钥对列表
     *
     * @param access 第三方API秘钥对
     * @return 第三方API秘钥对集合
     */
    public List<AccessVO> selectAccessList(AccessQuery access);

    /**
     * 新增第三方API秘钥对
     *
     * @param access 第三方API秘钥对
     * @return 结果
     */
    public int insertAccess(Access access);

    /**
     * 修改第三方API秘钥对
     *
     * @param access 第三方API秘钥对
     * @return 结果
     */
    public int updateAccess(Access access);

    /**
     * 批量删除第三方API秘钥对
     *
     * @param accessIds 需要删除的第三方API秘钥对主键集合
     * @return 结果
     */
    public int deleteAccessByAccessIds(List<Long> accessIds);

    /**
     * 删除第三方API秘钥对信息
     *
     * @param accessId 第三方API秘钥对主键
     * @return 结果
     */
    public int deleteAccessByAccessId(Long accessId);

    /**
     * 用户申请新的秘钥对
     *
     * @param userId 用户ID
     */
    AccessApplyVO apply(Long userId);

    /**
     * 查询用户秘钥对数量
     */
    int selectCountByUserId(Long userId);

    SmUserVo selectUserByAccess(String accessKey);

    /**
     * 根据accessKey查询秘钥对
     */
    AccessVO selectByAccessKey(String accessKey);

    /**
     * 删除缓存
     */
    boolean deleteCache(String accessKey);

    /**
     * 重置秘钥
     */
    String reset(Long accessId);
}
