package com.ruoyi.web.controller.app;

import com.fasterxml.jackson.annotation.JsonView;
import com.ruoyi.common.constant.HttpStatus;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.JsonViewProfile;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.enums.UserType;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.framework.web.service.SysPasswordService;
import com.ruoyi.framework.web.service.TokenService;
import com.ruoyi.ss.user.domain.bo.SmUserBO;
import com.ruoyi.ss.user.domain.SmUserVo;
import com.ruoyi.ss.user.domain.dto.UserRealNameDTO;
import com.ruoyi.ss.user.domain.dto.UserUpdatePasswordDTO;
import com.ruoyi.ss.user.service.ISmUserService;
import com.ruoyi.ss.user.service.UserAssembler;
import com.ruoyi.system.domain.enums.verificationCode.CodeBusinessType;
import com.ruoyi.system.service.IVerificationCodeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Collections;
import java.util.List;

/**
 * 用户信息Controller
 * @author 辉
 * 2024/3/6
 */
@Api(tags = "用户信息")
@RestController
@RequestMapping("/app/user")
public class AppUserController extends BaseController {

    @Autowired
    private ISmUserService userService;

    @Autowired
    private IVerificationCodeService verificationCodeService;

    @Autowired
    private UserAssembler userAssembler;

    @Autowired
    private SysPasswordService passwordService;

    @Autowired
    private TokenService tokenService;

    @ApiOperation("获取当前登录前台用户的信息")
    @GetMapping("/userInfo")
    @JsonView(JsonViewProfile.AppMch.class)
    public AjaxResult userInfo() {
        // 查询
        SmUserVo user = userService.selectSmUserByUserId(getUserId());
        ServiceUtil.assertion(user == null, "用户不存在", HttpStatus.UNAUTHORIZED);

        List<SmUserVo> list = Collections.singletonList(user);
        userService.desensitization(list);
        userAssembler.assembleStoreCount(list);
        userAssembler.assembleDeviceCount(list);
        return AjaxResult.success(user);
    }

    @ApiOperation("使用旧密码修改密码")
    @PutMapping("/updatePassword")
    public AjaxResult updatePassword( @RequestBody @Validated UserUpdatePasswordDTO dto) {
        SmUserVo user = userService.selectSmUserByUserId(getUserId());
        if (user == null) {
            return error("用户不存在");
        }
        // 若有设置旧密码，则应该判断旧密码是否正确
        if (StringUtils.hasText(user.getPassword()) && !passwordService.matches(user, dto.getOldPassword())) {
            return error("旧密码错误");
        }

        return toAjax(userService.updatePassword(getUserId(), dto.getNewPassword()));
    }

    @ApiOperation("退出登录")
    @DeleteMapping("/logout")
    public AjaxResult logout() {
        // 删除用户缓存记录
        LoginUser loginUser = SecurityUtils.getLoginUser();
        tokenService.delLoginUser(loginUser.getToken());
        return success();
    }

    @ApiOperation("用户实名认证")
    @PutMapping("/realName")
    public AjaxResult realName(@RequestBody @Validated UserRealNameDTO dto) {
        dto.setUserId(getUserId());
        return success(userService.realName(dto));
    }

    @ApiOperation("刷新用户实名认证结果")
    @GetMapping("/refreshRealName")
    public AjaxResult refreshRealName() {
        return toAjax(userService.refreshRealName(getUserId()));
    }

    @ApiOperation("标记用户已读商户协议")
    @PutMapping("/readMchLicence")
    public AjaxResult readMchLicence() {
        return toAjax(userService.readMchLicence(getUserId()));
    }

}
