package com.ruoyi.web.controller.ss;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.dashboard.DashboardService;
import com.ruoyi.ss.balancePeriod.domain.SmBalancePeriodQuery;
import com.ruoyi.ss.balancePeriod.service.ISmBalancePeriodService;
import com.ruoyi.ss.bonus.domain.BonusQuery;
import com.ruoyi.ss.bonus.service.BonusService;
import com.ruoyi.ss.businessRecord.service.ISmBusinessRecordService;
import com.ruoyi.ss.dashboard.ServiceIncomeQuery;
import com.ruoyi.ss.transactionBill.domain.TransactionBillQuery;
import com.ruoyi.ss.transactionBill.service.TransactionBillService;
import com.ruoyi.ss.transactionBill.domain.enums.TransactionBillGroupBy;
import com.ruoyi.ss.transactionBill.domain.enums.TransactionBillStatus;
import com.ruoyi.ss.businessRecord.domain.SmBusinessRecordVo;
import com.ruoyi.ss.dashboard.vo.BriefVo;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;

/**
 * 报表Controller
 * @author 辉
 * 2024/3/6
 */
@RestController
@RequestMapping("/system/dashboard")
public class SmDashboardController extends BaseController {

    @Autowired
    private TransactionBillService transactionBillService;

    @Autowired
    private ISmBalancePeriodService balancePeriodService;

    @Autowired
    private ISmBusinessRecordService businessRecordService;

    @Autowired
    private DashboardService dashboardService;

    @Autowired
    private BonusService bonusService;

    /**
     * 舆情分析数据
     */
    @GetMapping("/brief")
    public AjaxResult brief() {
        BriefVo brief = businessRecordService.selectBrief();

        Date today = new Date();
        Date startDate = DateUtils.plusDate(today, -12);
        Date endDate = DateUtils.plusDate(today, -1);
        List<SmBusinessRecordVo> history = businessRecordService.selectDailyLatest(startDate, endDate);

        brief.setHistory(history);

        return AjaxResult.success(brief);
    }

    /**
     * 获取账单分时统计数据
     * @param dto 查询条件
     * @return 统计数据
     */
    @GetMapping("/hourBillCount")
    public AjaxResult hourBillCount(@Validated(ValidGroup.Query.class) TransactionBillQuery dto) {
        dto.setGroupBy(TransactionBillGroupBy.create_hour.name());
        dto.setStatusList(TransactionBillStatus.serviceIncome());
        return AjaxResult.success(transactionBillService.selectCount(dto));
    }

    /**
     * 获取余额时段分析
     */
    @ApiOperation("获取余额时段分析")
    @GetMapping("/balancePeriod")
    public AjaxResult balancePeriod(SmBalancePeriodQuery dto) {
        return AjaxResult.success(balancePeriodService.selectSmBalancePeriodList(dto));
    }

    /**
     * 获取待办事项
     */
    @GetMapping("/todoList")
    public AjaxResult getTodoList() {
        return success(dashboardService.getTodoList());
    }

    /**
     * 获取服务费、收入及成本
     */
    @GetMapping("/serviceIncome")
    public AjaxResult getServiceIncome(ServiceIncomeQuery query) {
        return success(dashboardService.getServiceIncome(query));
    }

    /**
     * 按月统计分成
     */
    @GetMapping("/bonusMonthAmount")
    public AjaxResult getBonusMonthAmount(BonusQuery query) {
        return success(bonusService.selectMonthAmount(query));
    }

}
